==> helsinki_0.9.22.tar.gz: helsinki/vignettes/todo-datasets.md <==
helsinki - Potential data sources to be added
==========

* [Reittiopas API](http://developer.reittiopas.fi/pages/en/home.php)

* [Espoon rakennukst](http://www.hri.fi/fi/data/espoon-rakennukset/)
* [Vantaan rakennukset](http://www.hri.fi/fi/data/vantaan-rakennukset/)

Demography
* [Helsinki alueittain 2011](http://www.hri.fi/fi/data/helsinki-alueittain-2011-taulukot/) Tiedot Helsingin 8 suurpiirin ja 34 peruspiirin asukkaista, työpaikoista, asumisesta, rakentamisesta sekä palveluista ja palvelujen käytöstä.
* [Helsingin ja Helsingin seudun väestöennuste sukupuolen ja iän mukaan 2012-2050](http://www.hri.fi/fi/data/helsingin-ja-helsingin-seudun-vaestoennuste-sukupuolen-ja-ian-mukaan-2012-2050/)

General 
* [Helsingin kaupungin tilastollinen vuosikirja](http://www.hel2.fi/tietokeskus/data/helsingin_kaupungin_tilastollinen_vuosikirja_2009/index.html) Paljon lupaavan oloista dataa Excel-taulukkona,päivittynee vuosittain.  
* [Vuokrahinnat avoimena datana](http://valtioneuvosto.fi/ajankohtaista/tiedotteet/tiedote/fi.jsp?oid=357198)
* Implemented in get_hri_stats() (via HRI API) - [Helsingin seudun aluesarjat](http://www.aluesarjat.fi/)

Economic data
* Verotiedot postinumeroittain (Tilastokeskus)
* [Kuntien tilinpäätökset 2008-2010](http://www.hri.fi/fi/data/kuntien-tilinpaatokset-2008-2010/) - this data is available for all municipalities in Finland => could implement in sorvi
* [Helsingin kaupungin tulot ja menot 2009-2010](http://www.hri.fi/fi/data/helsingin-kaupunki-tulot-ja-menot-2009-ja-2010/)  
* [Helsingin kaupungin tulot ja menot 2012]( http://www.hri.fi/fi/data/helsingin-kaupungin-tulot-ja-menot/)  
* [Espoon kaupungin tulot ja menot 2011-2012](http://www.hri.fi/fi/data/espoon-kaupungin-tulot-ja-menot/)
* [Vantaan toimintamenot ja -tulot toimielimittäin 2009 – 2011](http://www.hri.fi/fi/data/vantaan-toimintamenot-ja-tulot-toimielimittain-2009-2011/) 
* [Kauniaisten kaupungin tulot ja menot 2012](http://www.hri.fi/fi/data/kauniaisten-kaupungin-tulot-ja-menot/)
* Implemented in get_economic_indicators() - [Pääkaupunkiseudun taloudellisia tunnuslukuja](http://www.hri.fi/fi/data/paakaupunkiseudun-kuntien-taloudellisia-tunnuslukuja/)  

Decision making
* [Open AHJO](http://dev.hel.fi/apis/openahjo)
* [Helsinkikanava](http://open.helsinkikanava.fi/) Helsinki city council meeting video recordings and associated metadata

Data catalogues
* [Finland local open data census](http://fi-city.census.okfn.org/)
* [HRI:n datakatalogi](http://www.hri.fi/fi/data-haku/)  
* [HRI-verkkopalvelun avoimen datan metatiedot](http://www.hri.fi/fi/data/hri-verkkopalvelun-avoimen-datan-metatiedot)

Traffic
* [Liikenneonnettomuudet Helsingissä 2000-2010](http://www.hri.fi/fi/data/liikenneonnettomuudet-helsingissa-2000-2010) tapahtumapaikat ja onnettomuuslaji paikkatietoaineistona. CSV- ja MapInfo-muotoinen ote liikenneonnettomuusrekisteristä
* [Liikennemäärät Helsingissä 2011](http://www.hri.fi/fi/data/liikennemaarat-helsingissa-2011) Ajoneuvojen (henkilöautojen, pakettiautojen, kuorma-autojen, rekka-autojen, linja-autojen, moottoripyörien) sekä raitiovaunujen liikennemääriä useissa laskentapisteissä.

==> helsinki_0.9.27.tar.gz: helsinki/vignettes/todo-datasets.md <==
helsinki - Potential data sources to be added
==========

* [Reittiopas API](http://developer.reittiopas.fi/pages/en/home.php) (Juuso has code in his drytrip-repo)
* [Matka-aika matriisi](http://blogs.helsinki.fi/saavutettavuus/data/metropaccess-matka-aikamatriisi/)
* [Espoon rakennukst](http://www.hri.fi/fi/data/espoon-rakennukset/)
* [Vantaan rakennukset](http://www.hri.fi/fi/data/vantaan-rakennukset/)

Demography
* [Helsinki alueittain 2011](http://www.hri.fi/fi/data/helsinki-alueittain-2011-taulukot/) Tiedot Helsingin 8 suurpiirin ja 34 peruspiirin asukkaista, työpaikoista, asumisesta, rakentamisesta sekä palveluista ja palvelujen käytöstä.
* [Helsingin ja Helsingin seudun väestöennuste sukupuolen ja iän mukaan 2012-2050](http://www.hri.fi/fi/data/helsingin-ja-helsingin-seudun-vaestoennuste-sukupuolen-ja-ian-mukaan-2012-2050/)

General 
* [Helsingin kaupungin tilastollinen vuosikirja](http://www.hel2.fi/tietokeskus/data/helsingin_kaupungin_tilastollinen_vuosikirja_2009/index.html) Paljon lupaavan oloista dataa Excel-taulukkona,päivittynee vuosittain.  
* [Vuokrahinnat avoimena datana](http://valtioneuvosto.fi/ajankohtaista/tiedotteet/tiedote/fi.jsp?oid=357198)
* Implemented in get_hri_stats() (via HRI API) - [Helsingin seudun aluesarjat](http://www.aluesarjat.fi/)

Economic data
* Verotiedot postinumeroittain (Tilastokeskus)
* [Kuntien tilinpäätökset 2008-2010](http://www.hri.fi/fi/data/kuntien-tilinpaatokset-2008-2010/) - this data is available for all municipalities in Finland => could implement in sorvi
* [Helsingin kaupungin tulot ja menot 2009-2010](http://www.hri.fi/fi/data/helsingin-kaupunki-tulot-ja-menot-2009-ja-2010/)  
* [Helsingin kaupungin tulot ja menot 2012]( http://www.hri.fi/fi/data/helsingin-kaupungin-tulot-ja-menot/)  
* [Espoon kaupungin tulot ja menot 2011-2012](http://www.hri.fi/fi/data/espoon-kaupungin-tulot-ja-menot/)
* [Vantaan toimintamenot ja -tulot toimielimittäin 2009 – 2011](http://www.hri.fi/fi/data/vantaan-toimintamenot-ja-tulot-toimielimittain-2009-2011/) 
* [Kauniaisten kaupungin tulot ja menot 2012](http://www.hri.fi/fi/data/kauniaisten-kaupungin-tulot-ja-menot/)
* Implemented in get_economic_indicators() - [Pääkaupunkiseudun taloudellisia tunnuslukuja](http://www.hri.fi/fi/data/paakaupunkiseudun-kuntien-taloudellisia-tunnuslukuja/)  

Decision making
* [Open AHJO](http://dev.hel.fi/apis/openahjo)
* [Helsinkikanava](http://open.helsinkikanava.fi/) Helsinki city council meeting video recordings and associated metadata

Data catalogues
* [Finland local open data census](http://fi-city.census.okfn.org/)
* [HRI:n datakatalogi](http://www.hri.fi/fi/data-haku/)  
* [HRI-verkkopalvelun avoimen datan metatiedot](http://www.hri.fi/fi/data/hri-verkkopalvelun-avoimen-datan-metatiedot)

Traffic
* [Liikenneonnettomuudet Helsingissä 2000-2010](http://www.hri.fi/fi/data/liikenneonnettomuudet-helsingissa-2000-2010) tapahtumapaikat ja onnettomuuslaji paikkatietoaineistona. CSV- ja MapInfo-muotoinen ote liikenneonnettomuusrekisteristä
* [Liikennemäärät Helsingissä 2011](http://www.hri.fi/fi/data/liikennemaarat-helsingissa-2011) Ajoneuvojen (henkilöautojen, pakettiautojen, kuorma-autojen, rekka-autojen, linja-autojen, moottoripyörien) sekä raitiovaunujen liikennemääriä useissa laskentapisteissä.
